## Synaptans WorkforceSim, version 0.1.912

Synaptans WorkforceSim is a free open-source platform for simulating the dynamics of a factory workforce and assessing various AI-based approaches to predictive analytics in the workplace. The program exists as a Python package that allows users to configure the simulation’s parameters, run the simulation, and view an array of charts and graphs that visualize the results. The simulation’s logic is intended to operate at four levels:

▶ LEVEL 0: “WORKFORCE CONSTRUCTION.” Here the software constructs a simulated workforce of a desired size, whose members possess a randomly-distributed array of demographic characteristics and abilities that will influence their daily behavior and performance in the workplace.

▶ LEVEL 1: “WORKERS’ BEHAVIORS.” Here the software simulates the concrete actions performed by frontline factory workers each day (e.g., by determining the actual degree of Efficacy with which each worker operates a production machine on a given day and determining exactly when workers cause workplace accidents or devise and implement business-process improvements).

▶ LEVEL 2: “MANAGERS’ RECORDS.” Here the software simulates the behavior of such workers’ immediate managers in noticing (or overlooking) and accurately (or inaccurately) recording workers’ actions in an HRM/ERP system that seeks to document workers’ performance.

▶ LEVEL 3: “AI-BASED ANALYSIS.” Here the software employs various forms of machine learning and AI to attempt to identify trends and causal connections, classify workers, and predict workers’ future behaviors on the basis of the information recorded by managers in the organization’s enterprise system at Level 2. Just as in a real workplace, the AI doesn’t have direct access to the sum of workers’ actual behaviors; it can only access, analyze, and draw conclusions on the basis of the data that have actually been recorded in an organization’s HRM/ERP systems – and depending on the degree of attentiveness, thoroughness, and fairness displayed by managers, such data may or may not accurately reflect the reality of workers’ actual behaviors.

▶ LEVEL 4: “ASSESSEMENT OF THE AI-BASED ANALYSIS.” In a real-world organization, it’s incredibly difficult to gauge the accuracy of AI-generated analysis of workers’ behaviors, as data scientists and senior executives have no access to what’s actually happening at Level 1; they only have access to the relatively tiny quantity of worker behaviors that are captured (often inaccurately) by information systems at Level 2. The utility of a workforce simulation like this one lies in the fact that we actually know the reality of each worker’s personality, capacities, and daily behaviors – because a user has specified (and is able to view) all workers’ characteristics (including attitudes, strengths, and weaknesses that are normally invisible in a workplace setting) and has algorithmically determined exactly what actions he or she performs each day. This makes it possible to compare AI-based analysis not only against the observations that managers recorded at Level 2 but against the actual behaviors performed by workers at Level 1 and the true capacities possessed by workers at Level 0. In this way, it becomes possible to evaluate which AI-based approaches can most accurately model workplace behaviors identify an organization’s best workers – and what degree of confidence can be placed in various forms of predictive analytics.

In the current version of the program, the code for Levels 0, 1, and 2 has been partially implemented and a development roadmap has been prepared for Levels 3-4. 

Synaptans WorkforceSim is developed by Matthew E. Gladden, with support from Cognitive Firewall LLC and NeuraXenetica LLC. The software is made available for use under GNU General Public License Version 3 (please see https://www.gnu.org/licenses/gpl-3.0.html).